Summary: imake source code configuration and build system
Name: imake
Version: 1.0.10
Release: 14%{?dist}2a
License: MIT
Group: User Interface/X
URL: http://www.x.org

Source0: https://www.x.org/pub/individual/util/imake-%{version}.tar.xz
Source1: https://www.x.org/pub/individual/util/makedepend-1.0.8.tar.xz
Source2: https://www.x.org/pub/individual/util/gccmakedep-1.0.3.tar.bz2
Source3: https://www.x.org/pub/individual/util/xorg-cf-files-1.0.8.tar.xz
Source4: https://www.x.org/pub/individual/util/lndir-1.0.4.tar.xz
Patch11: imake-1.0.2-abort.patch
Patch24: imake-1.0.9-macos13.patch
Patch25: imake-1.0.10-macos14.patch

BuildRequires: pkgconfig
BuildRequires: xorg-x11-util-macros
BuildRequires: xorg-x11-proto-devel
BuildRequires: gcc
# imake is not functional without cc
Requires:      gcc

BuildArch:      fat

Provides: ccmakedep cleanlinks gccmakedep lndir makedepend makeg
Provides: mergelib mkdirhier mkhtmlindex revpath xmkmf

%description
Imake is a deprecated source code configuration and build system which
has traditionally been supplied by and used to build the X Window System
in X11R6 and previous releases.  As of the X Window System X11R7 release,
the X Window system has switched to using GNU autotools as the primary
build system, and the Imake system is now deprecated, and should not be
used by new software projects.  Software developers are encouraged to
migrate software to the GNU autotools system.

%prep
%setup -q -c %{name}-%{version} -a1 -a2 -a3 -a4
mkdir ARM64
mv -f *-* ARM64
pushd ARM64
# imake patches
pushd %{name}-%{version}
%patch11 -p1 -b .abort
popd
%patch24 -p1 -b .macos13
%patch25 -p1 -b .macos14
popd
cp -a ARM64 X86_64


%build
pushd ARM64
export CFLAGS="-O3 -arch arm64 -I%{_includedir}"
export CPPFLAGS="-arch arm64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export FFLAGS="$CFLAGS"
export FCFLAGS="$CFLAGS"
export LDFLAGS="-arch arm64 -L%{_libdir}"
export CC=/opt/osxws/bin/gcc
export CXX=/opt/osxws/bin/g++
# Build everything
{
   for pkg in imake makedepend gccmakedep lndir xorg-cf-files ; do
      pushd $pkg-*
      case $pkg in
         imake|xorg-cf-files)
            %configure \
        	--host=%{_rpm_platform_arm64} \
        	--build=%{_rpm_platform_arm64} \
        	--target=%{_rpm_platform_arm64} \
		--with-config-dir=%{_datadir}/X11/config
            ;;
         *)
            %configure \
        	--host=%{_rpm_platform_arm64} \
        	--build=%{_rpm_platform_arm64} \
        	--target=%{_rpm_platform_arm64}
            ;;
      esac
      mv Makefile Makefile.orig
      sed -e 's;/usr/include;/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include;' Makefile.orig > Makefile
      make %{?_smp_mflags}
      popd
   done
}
popd

pushd X86_64
export CFLAGS="-O3 -arch x86_64 -I%{_includedir}"
export CPPFLAGS="-arch x86_64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export FFLAGS="$CFLAGS"
export FCFLAGS="$CFLAGS"
export LDFLAGS="-arch x86_64 -L%{_libdir}"
export CC=/opt/osxws/bin/gcc
export CXX=/opt/osxws/bin/g++
# Build everything
{
   for pkg in imake makedepend gccmakedep lndir xorg-cf-files ; do
      pushd $pkg-*
      case $pkg in
         imake|xorg-cf-files)
            %configure \
        	--host=%{_rpm_platform_x86_64} \
        	--build=%{_rpm_platform_arm64} \
        	--target=%{_rpm_platform_x86_64} \
		--with-config-dir=%{_datadir}/X11/config
            ;;
         *)
            %configure \
        	--host=%{_rpm_platform_x86_64} \
        	--build=%{_rpm_platform_arm64} \
        	--target=%{_rpm_platform_x86_64}
            ;;
      esac
      mv Makefile Makefile.orig
      sed -e 's;/usr/include;/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include;' Makefile.orig > Makefile
      arch -arch x86_64 \
      make %{?_smp_mflags}
      popd
   done
}
popd


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf $RPM_BUILD_ROOT
PWD=`pwd`
pushd ARM64
rm -rf ${PWD}-root
mkdir -p ${PWD}-root
# Install everything
{
   for pkg in imake makedepend gccmakedep lndir xorg-cf-files ; do
      pushd $pkg-*
	    make install DESTDIR=${PWD}/../../ARM64-root
      popd
   done
}
popd

pushd X86_64
rm -rf ${PWD}-root
mkdir -p ${PWD}-root
# Install everything
{
   for pkg in imake makedepend gccmakedep lndir xorg-cf-files ; do
      pushd $pkg-*
	    arch -arch x86_64 \
	    make install DESTDIR=${PWD}/../../X86_64-root
      popd
   done
}
popd

## Make Universal Binaries
filelist=$(find ./ARM64-root -type f | xargs file | sed -e 's,^\./ARM64-root/,,g' | \
        grep -E \(Mach-O\)\|\(ar\ archive\) |sed -e 's,:.*,,g' -e '/\for\ architecture/d')

for i in $filelist
do
        /usr/bin/lipo -create ARM64-root/$i X86_64-root/$i -output `basename $i` && \
        (cp -f `basename $i` ARM64-root/$i) || :
done

# check header files
for i in `find ARM64-root -name "*.h" -type f`
do
        TARGET=`echo $i | sed -e "s,.*ARM64-root,,"`
        TEMP=`diff -u ARM64-root/$TARGET X86_64-root/$TARGET > /dev/null || echo different`
        if [ -n "$TEMP" ]; then
                mv X86_64-root/$TARGET ARM64-root/${TARGET%.*}-x86_64.h
                mv ARM64-root/$TARGET ARM64-root/${TARGET%.*}-arm64.h
                FILE=${TARGET##*/}
                FILE=${FILE%.*}
cat <<EOF > ARM64-root/$TARGET
#if defined (__arm64__)
#include "${FILE}-arm64.h"
#elif defined( __x86_64__ )
#include "${FILE}-x86_64.h"
#endif
EOF
        fi
done

# install
mkdir -p %{buildroot}
tar cf - -C ARM64-root . | tar xpf - -C %{buildroot}

# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -rf $RPM_BUILD_ROOT%{_datadir}/common-lisp
rm -f $RPM_BUILD_ROOT%{_infodir}/dir


%clean
rm -rf $RPM_BUILD_ROOT

%files
%ifnos darwin
%defattr(-,root,root,-)
%else
%defattr(-,root,wheel,-)
%endif
%doc
%{_bindir}/ccmakedep
%{_bindir}/cleanlinks
%{_bindir}/gccmakedep
%{_bindir}/imake
%{_bindir}/lndir
%{_bindir}/makedepend
%{_bindir}/makeg
%{_bindir}/mergelib
%{_bindir}/mkdirhier
%{_bindir}/mkhtmlindex
%{_bindir}/revpath
%{_bindir}/xmkmf
%dir %{_datadir}/X11/config
%{_datadir}/X11/config/*.cf
%{_datadir}/X11/config/*.def
%{_datadir}/X11/config/*.rules
%{_datadir}/X11/config/*.tmpl
%{_mandir}/man1/ccmakedep.1*
%{_mandir}/man1/cleanlinks.1*
%{_mandir}/man1/gccmakedep.1*
%{_mandir}/man1/imake.1*
%{_mandir}/man1/lndir.1*
%{_mandir}/man1/makedepend.1*
%{_mandir}/man1/makeg.1*
%{_mandir}/man1/mergelib.1*
%{_mandir}/man1/mkdirhier.1*
%{_mandir}/man1/mkhtmlindex.1*
%{_mandir}/man1/revpath.1*
%{_mandir}/man1/xmkmf.1*

%changelog
* Wed Dec 11 2024 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.10-14hepx2a1
- 4th build and release on MacOS 14
- added macos14 patch to remove '-no-cpp-precomp'
- built with gcc14.2 on OSXWS 14 and provided as fat binaries

* Mon Dec 9 2024 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.10-14hepx1c
- 3rd build and release on MacOS 14
- built with gcc14.2 on OSXWS 14 and provided as fat binaries

* Sun Dec 8 2024 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.10-14hepx1b
- 2nd build and release on MacOS 14
- built with gcc15 on OSXWS 14 and provided as fat binaries

* Thu Dec 5 2024 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.10-14hepx1a
- 1st build and release of new upstream version on MacOS 14
- built with gcc14.1 on OSXWS 14 and provided as fat binaries

* Sat Oct 28 2023 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.9-13hepx1a
- 1st build and release of new upstream version on MacOS 13
- built with gcc on OSXWS 13 and provided as fat binaries

* Fri Oct 27 2023 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-13hepx12a
- 1st build and release on MacOS 13
- built with gcc on OSXWS 13 and provided as fat binaries

* Mon Apr 11 2022 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-12hepx11a
- 3rd build and release on MacOS 12
- unified and updated macos12 patch
- built with OSXWS 12beta

* Sat Feb 26 2022 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-12hepx10b
- 2nd build and release on MacOS 12
- built with OSXWS 12beta

* Fri Jan 28 2022 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-12hepx10a
- 1st build and release on MacOS 12
- built with OSXWS 11

* Wed Jan 22 2020 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-10.15hepx10a
- 2nd build and release on MacOSX 10.15
- built with OSXWS 10.15
- change the default system include dir.
- imake should be compiled with gcc not with clang.

* Wed Jan 22 2020 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-10.15hepx9a
- 1st build and release on MacOSX 10.15
- built with OSXWS 10.15
- imake should be compiled with gcc not with clang.

* Thu Dec 19 2019 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-10.14hepx9c
- 3rd build and release on MacOSX 10.14
- built with OSXWS 10.14
- added imake-1.0.7-gcc9.patch (-no-cpp-precomp now alien to gcc9)
- imake should be compiled with gcc not with clang.

* Thu Dec 19 2019 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-10.14hepx9b
- 2nd build and release on MacOSX 10.14
- built with OSXWS 10.14
- imake should be compiled with gcc not with clang.

* Mon Dec 24 2018 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-10.14hepx9a
- 1st build and release on MacOSX 10.14
- built with OSXWS 10.13
- imake should be compiled with gcc not with clang.

* Mon Apr 02 2018 Keisuke Fujii <keisuke.fujii@kek.jp> 1.0.7-10.13hepx9a
- 1st build and release on MacOSX 10.13
- built with OSXWS 10.13
- imake should be compiled with gcc not with clang.

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Oct 01 2014 Adam Jackson <ajax@redhat.com> 1.0.7-4
- imake 1.0.7
- gccmakedep 1.0.3

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Mar 17 2014 Marcin Juszkiewicz <mjuszkiewicz@redhat.com> - 1.0.6-2
- Backport AArch64 support

* Mon Jan 20 2014 Adam Jackson <ajax@redhat.com> 1.0.6-1
- imake 1.0.6

* Mon Dec 09 2013 Adam Jackson <ajax@redhat.com> 1.0.5-8
- Fix imake build with -Werror=format-security (#1037129)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 07 2013 Jon Ciesla <limburgher@gmail.com> 1.0.5-7
- Merge review fixes, BZ 225898.

* Thu Jan 03 2013 Adam Jackson <ajax@redhat.com> 1.0.5-6
- Drop unused patches

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Mar 08 2012 Adam Jackson <ajax@redhat.com> 1.0.5-4
- imake 1.0.5
- lndir 1.0.3
- makedepend 1.0.4
